@@ -37,3 +37,8 @@ to_json = function(x, ..., auto_unbox = TRUE, null = 'null') {
 random_port = function() servr::random_port(NULL)
 
 `%n%` = knitr:::`%n%`
+
+run_servr = function() {
+  # see https://github.com/rstudio/httpuv/issues/250
+  later::with_loop(later::global_loop(), httpuv::service(NA))
+}
